@@ -243,7 +243,7 @@ sub _return_callback {
             $info1 = sprintf _p_fmt( $opt, "info_row1" ),
                                 $prec, $p->{total} / 1024 ** $exp->{$unit}, $unit,
                                 'ETA ' . ( $eta || '-:--:--' ),
-                                $p->{kbs_avg} || '--',
+                                $p->{kbs_avg} || '--';
             $info2 = sprintf _p_fmt( $opt, "info_row2" ),
                                 $prec, $received / 1024 ** $exp->{$unit}, $unit,
                                 $p->{total} > $thresh ? 2 : 1, $percent,
