@@ -48,7 +48,7 @@ sub uploader_history_menu {
         elsif ( $choice eq $uploader ) {
             my ( $sticky,  $sticky_url ) = _sticky_name_and_url( $opt->{sticky} );
             my ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{history} );
-            my $prompt = 'Uploader:' . "\n";
+            my $prompt = 'Chosen:' . "\n";
             my @ids;
 
             CHANNEL: while ( 1 ) {
@@ -59,11 +59,13 @@ sub uploader_history_menu {
                 my @indexes = choose(
                     $choices,
                     { prompt => $prompt . "\nYour choice:", layout => 3, index => 1,
-                        undef => '  BACK', no_spacebar => [ 0 .. $#pre, $#$choices ] }
+                        undef => '  BACK', no_spacebar => [ 0 .. $#pre ] }
                 );
                 if ( ! $indexes[0] ) {
                     if ( @ids ) {
                         $prompt = 'Channels:' . "\n";
+                        ( $sticky,  $sticky_url ) = _sticky_name_and_url( $opt->{sticky} );
+                        ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{history} );
                         @ids = ();
                         next CHANNEL;
                     }
@@ -71,35 +73,30 @@ sub uploader_history_menu {
                         next MENU;
                     }
                 }
-                if ( $choices->[$indexes[0]] eq $confirm ) {
-                    shift @indexes;
-                    for my $i ( @indexes ) {
-                        $i -= @pre;
-                        if ( $i <= $#$sticky ) {
-                            push @ids, $sticky_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{sticky}{$sticky_url->[$i]}{uploader_id};
-                        }
-                        else {
-                            $i -= @$sticky;
-                            push @ids, $history_url->[$i];
-                            $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{history}{$history_url->[$i]}{uploader_id};
-                        }
-                    }
-                    return @ids;
-                }
                 else {
+                    my $confirmed;
+                    if ( $choices->[$indexes[0]] eq $confirm ) {
+                        shift @indexes;
+                        $confirmed = 1;
+                    }
+                    my $count = 0;
                     for my $i ( @indexes ) {
-                        $i -= @pre;
+                        $i -= @pre + $count;
                         if ( $i <= $#$sticky ) {
-                            push @ids, $sticky_url->[$i];
                             $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{sticky}{$sticky_url->[$i]}{uploader_id};
+                            push @ids, splice @$sticky_url, $i, 1;
+                                       splice @$sticky    , $i, 1;
                         }
                         else {
                             $i -= @$sticky;
-                            push @ids, $history_url->[$i];
                             $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{history}{$history_url->[$i]}{uploader_id};
+                            push @ids, splice @$history_url,  $i, 1;
+                                       splice @$history,      $i, 1;
+                                       splice @$removed_next, $i, 1;
                         }
+                        $count++;
                     }
+                    return @ids if $confirmed;
                 }
             }
         }
