@@ -15,7 +15,7 @@ use Text::LineFold     qw();
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::GetData qw( get_download_info );
-
+use App::YTDL::Helper  qw( check_mapping_stdout );
 
 
 sub _download_info {
@@ -52,6 +52,7 @@ sub _prepare_print_info {
     for my $key ( @keys ) {
         next if ! $info->{$ex}{$video_id}{$key};
         $info->{$ex}{$video_id}{$key} =~ s/\R/ /g;
+        $info->{$ex}{$video_id}{$key} = check_mapping_stdout( $opt, $info->{$ex}{$video_id}{$key} );
     }
     return @keys;
 }
