@@ -187,6 +187,11 @@ sub set_options {
     for my $key ( %$sub_menus ) {
         push @keys, map { $_->[0] } @{$sub_menus->{$key}};
     }
+
+    ### ###
+    push @keys, 'history_files_checked' if exists $opt->{history_files_checked};
+    ###
+
     my $group = 'main';
     my $backup_old_idx = 0;
     my $old_idx = 0;
