@@ -36,7 +36,7 @@ sub set_preferred_qualities {
             push @format_ids, $fmt;
         }
     }
-    my $pref_qual = read_json( $opt, $opt->{preferred_file} );
+    my $pref_qual = read_json( $opt, $opt->{preferred_file} ) // {};
 
     CHOICE: while ( 1 ) {
         my @pre = ( undef );
@@ -106,8 +106,8 @@ sub fmt_quality {
 
     }
     elsif ( $auto_quality eq 'preferred' ) {
-        my $pref_qual = read_json( $opt, $opt->{preferred_file} );
-        my @pref_qualities = @{$pref_qual->{$ex}};
+        my $pref_qual = read_json( $opt, $opt->{preferred_file} ) // {};
+        my @pref_qualities = @{$pref_qual->{$ex}//[]};
         PQ: for my $slot ( @pref_qualities ) {
             for my $fmt ( @$slot ) {
                 $fmt_ok = 1;
